@@ -191,9 +191,9 @@ void Selection::moveTo(const Position &pos)
 
 void Selection::moveTo(const Position &base, const Position &extent)
 {
-//   kdDebug(6200) << "Selection::moveTo: base(" << base.node() << "," << base.offset() << "), extent(" << extent.node() << "," << extent.offset() << ")" << endl;
+//   kdDebug(6200) << "Selection::moveTo: base(" << base.node() << "," << base.offset() << "), extent(" << extent.node() << "," << extent.offset() << ")";
 #ifdef DEBUG_CARET
-    qDebug() << *this << base << extent << endl;
+    qCDebug(KHTML_LOG) << *this << base << extent;
 #endif
     assignBaseAndExtent(base, extent);
     validate();
@@ -410,7 +410,7 @@ void Selection::setNeedsLayout(bool flag)
 void Selection::getRange(NodeImpl *&st, long &so, NodeImpl *&en, long &eo) const
 {
     if (isEmpty()) {
-        st = en = 0; so = eo = 0;
+        st = en = nullptr; so = eo = 0;
         return;
     }
 
@@ -481,11 +481,11 @@ void Selection::layoutCaret()
         int w;
         int offset = RenderPosition::fromDOMPosition(caretPos()).renderedOffset();
 #ifdef DEBUG_CARET
-        qDebug() << "[before caretPos()]" << m_caretX << endl;
+        qCDebug(KHTML_LOG) << "[before caretPos()]" << m_caretX;
 #endif
         caretPos().node()->renderer()->caretPos(offset, true, m_caretX, m_caretY, w, m_caretSize);
 #ifdef DEBUG_CARET
-        qDebug() << "[after caretPos()]" << m_caretX << endl;
+        qCDebug(KHTML_LOG) << "[after caretPos()]" << m_caretX;
 #endif
     }
 
@@ -521,7 +521,7 @@ void Selection::needsCaretRepaint()
         return;
     }
 
-    // qDebug() << "[NeedsCaretLayout]" << m_needsCaretLayout << endl;
+    // qCDebug(KHTML_LOG) << "[NeedsCaretLayout]" << m_needsCaretLayout;
     if (m_needsCaretLayout) {
         // repaint old position and calculate new position
         v->updateContents(getRepaintRect());
@@ -581,13 +581,13 @@ void Selection::paintCaret(QPainter *p, const QRect &rect)
 void Selection::validate(ETextGranularity granularity)
 {
 #ifdef DEBUG_CARET
-    qDebug() << *this << granularity << endl;
+    qCDebug(KHTML_LOG) << *this << granularity;
 #endif
     // move the base and extent nodes to their equivalent leaf positions
     bool baseAndExtentEqual = base() == extent();
     if (base().notEmpty()) {
 #ifdef DEBUG_CARET
-        qDebug() << "[base not empty]" << endl;
+        qCDebug(KHTML_LOG) << "[base not empty]";
 #endif
         Position pos = base().equivalentLeafPosition();
         assignBase(pos);
@@ -627,7 +627,7 @@ void Selection::validate(ETextGranularity granularity)
     // calculate the correct start and end positions
     if (granularity == CHARACTER) {
 #ifdef DEBUG_CARET
-        qDebug() << "[character:baseIsStart]" << m_baseIsStart << base() << extent() << endl;
+        qCDebug(KHTML_LOG) << "[character:baseIsStart]" << m_baseIsStart << base() << extent();
 #endif
         if (m_baseIsStart) {
             assignStartAndEnd(base(), extent());
@@ -640,18 +640,18 @@ void Selection::validate(ETextGranularity granularity)
         int extentStartOffset = extent().offset();
         int extentEndOffset = extent().offset();
 #ifdef DEBUG_CARET
-        qDebug() << "WORD GRANULARITY:" << baseStartOffset << baseEndOffset << extentStartOffset << extentEndOffset << endl;
+        qCDebug(KHTML_LOG) << "WORD GRANULARITY:" << baseStartOffset << baseEndOffset << extentStartOffset << extentEndOffset;
 #endif
         if (base().notEmpty() && (base().node()->nodeType() == Node::TEXT_NODE || base().node()->nodeType() == Node::CDATA_SECTION_NODE)) {
             DOMString t = base().node()->nodeValue();
             QChar *chars = t.unicode();
             uint len = t.length();
 #ifdef DEBUG_CARET
-            qDebug() << "text:" << QString::fromRawData(chars, len) << endl;
+            qCDebug(KHTML_LOG) << "text:" << QString::fromRawData(chars, len);
 #endif
             findWordBoundary(chars, len, base().offset(), &baseStartOffset, &baseEndOffset);
 #ifdef DEBUG_CARET
-            qDebug() << "after find word boundary" << baseStartOffset << baseEndOffset << endl;
+            qCDebug(KHTML_LOG) << "after find word boundary" << baseStartOffset << baseEndOffset;
 #endif
         }
         if (extent().notEmpty() && (extent().node()->nodeType() == Node::TEXT_NODE || extent().node()->nodeType() == Node::CDATA_SECTION_NODE)) {
@@ -659,15 +659,15 @@ void Selection::validate(ETextGranularity granularity)
             QChar *chars = t.unicode();
             uint len = t.length();
 #ifdef DEBUG_CARET
-            qDebug() << "text:" << QString::fromRawData(chars, len) << endl;
+            qCDebug(KHTML_LOG) << "text:" << QString::fromRawData(chars, len);
 #endif
             findWordBoundary(chars, len, extent().offset(), &extentStartOffset, &extentEndOffset);
 #ifdef DEBUG_CARET
-            qDebug() << "after find word boundary" << baseStartOffset << baseEndOffset << endl;
+            qCDebug(KHTML_LOG) << "after find word boundary" << baseStartOffset << baseEndOffset;
 #endif
         }
 #ifdef DEBUG_CARET
-        qDebug() << "is start:" << m_baseIsStart << endl;
+        qCDebug(KHTML_LOG) << "is start:" << m_baseIsStart;
 #endif
         if (m_baseIsStart) {
             assignStart(Position(base().node(), baseStartOffset));
@@ -891,8 +891,8 @@ static bool startAndEndLineNodesIncludingNode(NodeImpl *node, int offset, Select
             renderNode = renderNode->firstChild();
         }
 
-        NodeImpl *startNode = 0;
-        NodeImpl *endNode = 0;
+        NodeImpl *startNode = nullptr;
+        NodeImpl *endNode = nullptr;
         long startOffset;
         long endOffset;
 
@@ -1005,7 +1005,7 @@ void Selection::debugPosition() const
         Position pos = start();
         Position upstream = pos.equivalentUpstreamPosition();
         Position downstream = pos.equivalentDownstreamPosition();
-        /*FIXME:use qDebug() fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
+        /*FIXME:use qCDebug(KHTML_LOG) fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
             , upstream.node(), upstream.offset());
         fprintf(stderr, "pos:        %s %p:%ld\n", getTagName(pos.node()->id())
             , pos.node(), pos.offset());
@@ -1015,7 +1015,7 @@ void Selection::debugPosition() const
         Position pos = start();
         Position upstream = pos.equivalentUpstreamPosition();
         Position downstream = pos.equivalentDownstreamPosition();
-        /*FIXME: use qDebug() fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
+        /*FIXME: use qCDebug(KHTML_LOG) fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
             , upstream.node(), upstream.offset());
         fprintf(stderr, "start:      %s %p:%ld\n", getTagName(pos.node()->id())
             , pos.node(), pos.offset());
@@ -1025,7 +1025,7 @@ void Selection::debugPosition() const
         pos = end();
         upstream = pos.equivalentUpstreamPosition();
         downstream = pos.equivalentDownstreamPosition();
-        /*FIXME: use qDebug() fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
+        /*FIXME: use qCDebug(KHTML_LOG) fprintf(stderr, "upstream:   %s %p:%ld\n", getTagName(upstream.node()->id())
             , upstream.node(), upstream.offset());
         fprintf(stderr, "end:        %s %p:%ld\n", getTagName(pos.node()->id())
             , pos.node(), pos.offset());
